@@ -14,6 +14,8 @@
 #include <QStyle>
 #include <QToolButton>
 
+#include <type_traits>
+
 namespace QtUtilities {
 
 enum { BrushRole = 33 };
@@ -29,7 +31,6 @@ PaletteEditor::PaletteEditor(QWidget *parent)
 {
     m_ui->setupUi(this);
     m_ui->paletteView->setModel(m_paletteModel);
-    updatePreviewPalette();
     updateStyledButton();
     m_ui->paletteView->setModel(m_paletteModel);
     auto *const delegate = new ColorDelegate(this);
@@ -72,8 +73,9 @@ void PaletteEditor::setPalette(const QPalette &palette)
                       resolve()
 #endif
         ;
+    using MaskType = std::remove_cv_t<decltype(mask)>;
     for (int i = 0; i < static_cast<int>(QPalette::NColorRoles); ++i) {
-        if (mask & (1 << i)) {
+        if (mask & (static_cast<MaskType>(1) << static_cast<MaskType>(i))) {
             continue;
         }
         m_editPalette.setBrush(
@@ -91,7 +93,6 @@ void PaletteEditor::setPalette(const QPalette &palette)
         resolve(mask)
 #endif
         ;
-    updatePreviewPalette();
     updateStyledButton();
     m_paletteUpdated = true;
     if (!m_modelUpdated) {
@@ -106,6 +107,17 @@ void PaletteEditor::setPalette(const QPalette &palette, const QPalette &parentPa
     setPalette(palette);
 }
 
+bool PaletteEditor::event(QEvent *event)
+{
+    switch (event->type()) {
+    case QEvent::LanguageChange:
+        m_ui->retranslateUi(this);
+        break;
+    default:;
+    }
+    return QDialog::event(event);
+}
+
 void PaletteEditor::handleComputeRadioClicked()
 {
     if (m_compute) {
@@ -182,6 +194,8 @@ void PaletteEditor::load()
     auto errorMessage = QString();
     if (loadPalette(dialog.selectedFiles().constFirst(), &pal, &errorMessage)) {
         setPalette(pal);
+        // apply again as otherwise highlight and possibly other roles are not shown until the next restart
+        setPalette(pal, pal);
     } else {
         QMessageBox::warning(this, tr("Error reading palette"), errorMessage);
     }
@@ -217,21 +231,6 @@ void PaletteEditor::buildPalette()
     setPalette(temp);
 }
 
-void PaletteEditor::updatePreviewPalette()
-{
-    const QPalette::ColorGroup g = currentColorGroup();
-    // build the preview palette
-    const QPalette currentPalette = palette();
-    QPalette previewPalette;
-    for (int i = QPalette::WindowText; i < QPalette::NColorRoles; ++i) {
-        const QPalette::ColorRole r = static_cast<QPalette::ColorRole>(i);
-        const QBrush br = currentPalette.brush(g, r);
-        previewPalette.setBrush(QPalette::Active, r, br);
-        previewPalette.setBrush(QPalette::Inactive, r, br);
-        previewPalette.setBrush(QPalette::Disabled, r, br);
-    }
-}
-
 void PaletteEditor::updateStyledButton()
 {
     m_ui->buildButton->setColor(palette().color(QPalette::Active, QPalette::Button));
@@ -248,8 +247,9 @@ QPalette PaletteEditor::getPalette(QWidget *parent, const QPalette &init, const
                       resolve()
 #endif
         ;
+    using MaskType = std::remove_cv_t<decltype(mask)>;
     for (int i = 0; i < static_cast<int>(QPalette::NColorRoles); ++i) {
-        if (mask & (1 << i)) {
+        if (mask & (static_cast<MaskType>(1) << static_cast<MaskType>(i))) {
             continue;
         }
         parentPalette.setBrush(
@@ -308,9 +308,8 @@ QVariant PaletteModel::data(const QModelIndex &index, int role) const
                               resolve()
 #endif
                 ;
-            if (mask & (1 << index.row()))
-                return true;
-            return false;
+            using MaskType = std::remove_cv_t<decltype(mask)>;
+            return mask & (static_cast<MaskType>(1) << static_cast<MaskType>(index.row()));
         }
         return QVariant();
     }
@@ -377,7 +376,7 @@ bool PaletteModel::setData(const QModelIndex &index, const QVariant &value, int
         const bool isMask = qvariant_cast<bool>(value);
         const int r = index.row();
         if (isMask) {
-            mask |= (1 << r);
+            mask |= (static_cast<decltype(mask)>(1) << static_cast<decltype(mask)>(r));
         } else {
             m_palette.setBrush(
                 QPalette::Active, static_cast<QPalette::ColorRole>(r), m_parentPalette.brush(QPalette::Active, static_cast<QPalette::ColorRole>(r)));
@@ -385,7 +384,7 @@ bool PaletteModel::setData(const QModelIndex &index, const QVariant &value, int
                 m_parentPalette.brush(QPalette::Inactive, static_cast<QPalette::ColorRole>(r)));
             m_palette.setBrush(QPalette::Disabled, static_cast<QPalette::ColorRole>(r),
                 m_parentPalette.brush(QPalette::Disabled, static_cast<QPalette::ColorRole>(r)));
-            mask &= ~static_cast<decltype(mask)>(1 << index.row());
+            mask &= ~static_cast<decltype(mask)>((static_cast<decltype(mask)>(1) << static_cast<decltype(mask)>(index.row())));
         }
         m_palette.
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
